%define major      1
%define libname    %mklibname %{name} %{major}
%define devname    %mklibname %{name} -d
%define staticname %mklibname %{name} -d -s

Name:           irrlicht
Version:        1.8.5
Release:        %mkrel 2
Summary:        The Irrlicht Engine SDK
Group:          Graphics/3D
License:        zlib
URL:            https://irrlicht.sourceforge.net/
Source0:        https://downloads.sf.net/irrlicht/%{name}-%{version}.zip
Patch1:         irrlicht-1.8-library-makefile.patch
Patch2:         irrlicht-1.8-use-system-libs.patch
Patch3:         irrlicht-1.8.1-mga-system-glext.patch
Patch4:         irrlicht-1.8.1-fdr-mesa10.patch

BuildRequires:  bzip2-devel
BuildRequires:  imagemagick
BuildRequires:  pkgconfig(libjpeg)
# FIXME: Unbundle lzmadec once our system version is updated
#BuildRequires:  lzmadec-devel
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xft)
BuildRequires:  pkgconfig(xxf86vm)
BuildRequires:  pkgconfig(zlib)

%description
The Irrlicht Engine is an open source high performance realtime
3D engine written and usable in C++ and also available for .NET
languages. It is completely cross-platform, using D3D, OpenGL
and its own software renderer, and has all of the state-of-the-art
features which can be found in commercial 3D engines.

We've got a huge active community, and there are lots of projects
in development that use the engine. You can find enhancements for
Irrlicht all over the web, like alternative terrain renderers,
portal renderers, exporters, world layers, tutorials, editors,
language bindings for java, perl, ruby, basic, python, lua, and so
on. And best of all: It's completely free.

%package -n %{libname}
Summary:        Shared libraries for Irrlicht 3D engine
Group:          System/Libraries

%description -n %{libname}
The Irrlicht Engine is an open source high performance realtime
3D engine written and usable in C++ and also available for .NET
languages. It is completely cross-platform, using D3D, OpenGL
and its own software renderer, and has all of the state-of-the-art
features which can be found in commercial 3D engines.

We've got a huge active community, and there are lots of projects
in development that use the engine. You can find enhancements for
Irrlicht all over the web, like alternative terrain renderers,
portal renderers, exporters, world layers, tutorials, editors,
language bindings for java, perl, ruby, basic, python, lua, and so
on. And best of all: It's completely free.

%package -n %{devname}
Summary:        Development files for Irrlicht 3D engine
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}-%{release}

%description -n %{devname}
Development files for Irrlicht 3D engine.

%prep
%autosetup -p1

# make readme.txt and changes.txt utf8 with LF line endings
sed -i 's/\r//' readme.txt changes.txt
iconv -o readme.txt.utf8 -f iso88591 -t utf8 readme.txt
mv readme.txt.utf8 readme.txt

# use system wide libs, see patch2
rm -rf source/Irrlicht/{bzip2,jpeglib,libpng,zlib}

# https://bugzilla.redhat.com/show_bug.cgi?id=1035757
sed -i -e '/_IRR_MATERIAL_MAX_TEXTURES_/s/4/8/' include/IrrCompileConfig.h

%build
%set_build_flags
%make_build -C source/Irrlicht sharedlib NDEBUG=1

%install
# FIXME: Fix bogus upstream Makefile and make a PR
mkdir -p %{buildroot}%{_libdir}
%make_install -C source/Irrlicht INSTALL_DIR=%{buildroot}%{_libdir}
ln -s libIrrlicht.so.%{version} %{buildroot}%{_libdir}/libIrrlicht.so.%{major}

mkdir -p %{buildroot}%{_includedir}/%{name}
cp -a include/*.h %{buildroot}%{_includedir}/%{name}/

%files -n %{libname}
%{_libdir}/libIrrlicht.so.%{major}{,.*}

%files -n %{devname}
%{_includedir}/%{name}/
%{_libdir}/libIrrlicht.so


%changelog
* Wed Jun 18 2025 daviddavid <daviddavid> 1.8.5-2.mga10
+ Revision: 2192677
- rebuild for gcc15

* Thu Mar 31 2022 umeabot <umeabot> 1.8.5-2.mga9
+ Revision: 1837116
- Mageia 9 Mass Rebuild

* Fri Nov 12 2021 luigiwalser <luigiwalser> 1.8.5-1.mga9
+ Revision: 1755984
- 1.8.5
- remove patch 8 (fixed upstream)

* Fri Nov 27 2020 tv <tv> 1.8.4-4.mga8
+ Revision: 1649742
- Fix building with glibc-2.32

* Thu Feb 13 2020 umeabot <umeabot> 1.8.4-3.mga8
+ Revision: 1513663
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%setup_compile_flags

* Sun Sep 23 2018 umeabot <umeabot> 1.8.4-2.mga7
+ Revision: 1298325
- Mageia 7 Mass Rebuild

* Fri Aug 26 2016 akien <akien> 1.8.4-1.mga6
+ Revision: 1049176
- Bugfix version 1.8.4

* Thu Feb 11 2016 umeabot <umeabot> 1.8.3-2.mga6
+ Revision: 954622
- Mageia 6 Mass Rebuild

* Sun Sep 20 2015 akien <akien> 1.8.3-1.mga6
+ Revision: 881899
- Version 1.8.3
- Drop static lib, tools, examples, media and doc

* Sat Aug 22 2015 akien <akien> 1.8.1-6.mga6
+ Revision: 868070
- Rebuild for gcc 5.2.1

* Wed Oct 15 2014 umeabot <umeabot> 1.8.1-5.mga5
+ Revision: 744422
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.8.1-4.mga5
+ Revision: 680568
- Mageia 5 Mass Rebuild

* Thu Dec 19 2013 dams <dams> 1.8.1-3.mga4
+ Revision: 558718
- new tarball from upstream to fix Makefile
- clean specfile
- use new file for icon to prevent ugly rendering

* Tue Dec 17 2013 akien <akien> 1.8.1-2.mga4
+ Revision: 558320
- Add patch to use system-wide glext.h and glxext.h
- Add patch from Fedora to fix the build with mesa 10.0

* Thu Nov 28 2013 dams <dams> 1.8.1-1.mga4
+ Revision: 553834
- new version 1.8.1

* Mon Oct 21 2013 umeabot <umeabot> 1.8-2.mga4
+ Revision: 539741
- Mageia 4 Mass Rebuild

* Tue Oct 08 2013 dams <dams> 1.8-1.mga4
+ Revision: 492844
- drop unused requires
- new version 1.8 (it was a SVN snapshot before)
- rediff patches (with the help of Akien)
- clean specfile

* Mon Jun 03 2013 fwang <fwang> 1.8-0.svn4094.7.mga4
+ Revision: 435592
- drop unused requires

* Sun Jun 02 2013 fwang <fwang> 1.8-0.svn4094.6.mga4
+ Revision: 434872
- rebuild for new libpng

* Sat Jan 12 2013 umeabot <umeabot> 1.8-0.svn4094.5.mga3
+ Revision: 354498
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Jan 06 2013 barjac <barjac> 1.8-0.svn4094.4.mga3
+ Revision: 339631
- update desktop files

* Sat Jan 05 2013 barjac <barjac> 1.8-0.svn4094.3.mga3
+ Revision: 339475
- updated 2 more sub-package groups
- update doc group
- make doc sub-package noarch
- update group
- fix some rpmlint warnings

* Tue Apr 03 2012 luigiwalser <luigiwalser> 1.8-0.svn4094.2.mga2
+ Revision: 228080
- add patch0 for potential buffer overflow (similar to CVE-2011-4620)

* Mon Mar 05 2012 dams <dams> 1.8-0.svn4094.1.mga2
+ Revision: 218620
- new version 1.8 (svn snapshot 4094)
- rediff patchs
- clean and reorganize spec file

* Mon Sep 12 2011 fwang <fwang> 1.7.2-2.mga2
+ Revision: 142584
- more libpng1.5 patch
- cleanup br
- add gentoo patch to build with libpng 1.5
- rebuild for new libpng

* Wed Apr 20 2011 dams <dams> 1.7.2-1.mga1
+ Revision: 89105
- Clean and update patchs
- Disable patch #1
- Disable patch #1
- Update to 1.7.2

* Fri Mar 25 2011 dams <dams> 1.6.1-1.mga1
+ Revision: 77378
- Import and clean
- imported package irrlicht


* Mon Feb 01 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 1.6.1-1mdv2010.1
+ Revision: 499316
- update to new version 1.6.1
- rediff patch 1

* Sat Jan 30 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 1.6-1mdv2010.1
+ Revision: 498543
- update to new version 1.6
- rediff patches 1,3,4 and 6
- switch local headers to a system-wide
- export %%ldflags
- fix a lof of underlinking issues

* Sun Sep 27 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 1.5.1-2mdv2010.0
+ Revision: 450183
- fix creating of symlinks to main library
- Patch7: fix build against glext
- clean a little bit this mess ;)

* Tue Aug 18 2009 Frederik Himpe <fhimpe@mandriva.org> 1.5.1-1mdv2010.0
+ Revision: 417487
- Update to new version 1.5.1
- Rediff GUIEditor makefile patch

* Tue Dec 16 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1.5-1mdv2009.1
+ Revision: 314981
- Patch1: rediff to meet nofuzz
- Patch4: rediff to meet nofuzz
- add buildrequires on libxft-devel
- bump minor
- update to new version 1.5

* Mon Sep 22 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1.4.2-1mdv2009.1
+ Revision: 287150
- update to new version 1.4.2
- Patch1: rediff
- fix underlinking for all patches

* Thu Aug 07 2008 Thierry Vignaud <tvignaud@mandriva.com> 1.4.1-2mdv2009.0
+ Revision: 267168
- rebuild early 2009.0 package (before pixel changes)

  + Pixel <pixel@mandriva.com>
    - rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Thu Jun 05 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1.4.1-1mdv2009.0
+ Revision: 215241
- Patch6: rediff
- update to new version 1.4.1

* Sun Mar 09 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1.4-3mdv2008.1
+ Revision: 183144
- rebuild

  + Thierry Vignaud <tvignaud@mandriva.com>
    - fix no-buildroot-tag

* Wed Jan 02 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1.4-2mdv2008.1
+ Revision: 140520
- rework patch 1
- compile examples with %%optflags
- add missing requires on libname for subpackages

* Wed Jan 02 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1.4-1mdv2008.1
+ Revision: 140285
- finally make it compiles on both architecures ;)
- rework almost all patches
- add patch 5, probably a nVidia issue
- enable tools building
- provide exapmples, media and doc subpackages
- compile with -fPIC on x86_64
- drop patch 0, fixed upstream
- rediff patch 1
- add patches 3 and 4
- build without debug symbols
- kill icon extension for desktop files
- fix categories in desktop files
- add %%{minor} just to be sane
- new version
- add more provides on devel package

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request
    - kill desktop-file-validate's 'warning: key "Encoding" in group "Desktop Entry" is deprecated'

* Thu Aug 16 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1.3.1-1mdv2008.0
+ Revision: 64639
- compile with -fPIC
- really provide only libraries for now
- rediff all patches
- build only libraries
- Import irrlicht

